minor

# XMLRésuméLibrary: User Guide

middlenames | Element Reference | misc

## Name

minor — A minor course of study

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `major` element names the main (“major”) course of study in a degree. A major is the area that is focused on the most by a student.

### Parents

`minor` may be contained in these elements: `degree`

## See Also

`major`.

## Examples

For examples, see `degree`.

middlenames | Element Reference | misc